#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2021  Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

Name:       qubes-desktop-linux-menu
Version:	1.1.0
Release:	1%{dist}
Summary:	Qubes Application Menu

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org
Source0:    %{name}-%{version}.tar.gz

# because we have "#!/usr/bin/env python" shebangs, RPM puts
# "Requires: $(which # python)" dependency, which, depending on $PATH order,
# may point to /usr/bin/python or /bin/python (because Fedora has this stupid
# /bin -> usr/bin symlink). python*.rpm provides only /usr/bin/python.
AutoReq:	no

BuildArch: noarch

BuildRequires:  make
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  gettext

Requires:  python%{python3_pkgversion}-setuptools
Requires:  python%{python3_pkgversion}-gbulb
Requires:  gtk3
Requires:  python%{python3_pkgversion}-qubesadmin >= 4.1.8
Requires:  qubes-artwork >= 4.1.5

Provides:   qubes_menu = %{version}-%{release}


%description
A Qubes-specific Application menu.

%prep
%setup

%build
%py3_build

%install
%py3_install
make install DESTDIR=$RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ]; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%defattr(-,root,root,-)

%dir %{python3_sitelib}/qubes_menu-*.egg-info
%{python3_sitelib}/qubes_menu-*.egg-info/*


%dir %{python3_sitelib}/qubes_menu
%dir %{python3_sitelib}/qubes_menu/__pycache__
%{python3_sitelib}/qubes_menu/__pycache__/*
%{python3_sitelib}/qubes_menu/__init__.py
%{python3_sitelib}/qubes_menu/appmenu.py
%{python3_sitelib}/qubes_menu/app_widgets.py
%{python3_sitelib}/qubes_menu/application_page.py
%{python3_sitelib}/qubes_menu/constants.py
%{python3_sitelib}/qubes_menu/custom_widgets.py
%{python3_sitelib}/qubes_menu/desktop_file_manager.py
%{python3_sitelib}/qubes_menu/favorites_page.py
%{python3_sitelib}/qubes_menu/page_handler.py
%{python3_sitelib}/qubes_menu/search_page.py
%{python3_sitelib}/qubes_menu/settings_page.py
%{python3_sitelib}/qubes_menu/utils.py
%{python3_sitelib}/qubes_menu/vm_manager.py
%{python3_sitelib}/qubes_menu/qubes-menu.glade
%{python3_sitelib}/qubes_menu/qubes-menu-dark.css
%{python3_sitelib}/qubes_menu/qubes-menu-light.css
%{python3_sitelib}/qubes_menu/qubes-menu-base.css

%{_bindir}/qubes-app-menu
/usr/share/icons/hicolor/scalable/apps/qappmenu-dispvm-child.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-favorites.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-favorites-blue.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-grab-handle.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-networking-no.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-networking-vpn.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-networking-yes.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-power.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-qube.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-search.svg
/usr/share/icons/hicolor/scalable/apps/qappmenu-settings.svg

/etc/xdg/autostart/qubes-app-menu.desktop
/usr/share/applications/open-qubes-app-menu.desktop

/lib/systemd/user/qubes-app-menu.service
/usr/share/dbus-1/services/dbus-qubes-app-menu.service

%changelog
* Sun Apr 16 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-desktop-linux-menu.git

* Sun Apr 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cae3030
- version 1.1.0

* Tue Apr 11 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 9a0c9f7
- Fix event return value

* Tue Mar 07 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - be06e5a
- Improve keyboard navigation

* Thu Mar 02 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 9bf447c
- Add light mode to menu

* Wed Mar 01 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 4a3f36d
- Improve keyboard navigation

* Tue Feb 28 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - c4735fb
- Bunch of menu fixes

* Sat Feb 18 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3c7be17
- version 1.0.3

* Fri Feb 17 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 3c0cc45
- Don't assume system dirs exist

* Thu Feb 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d47acae
- version 1.0.2

* Wed Feb 15 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - bcbb629
- Try to wrangle menu into having correct env vars set

* Fri Feb 10 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - a9471e5
- Improve readability on normal DPI systems

* Wed Feb 08 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 4477562
- Set KillMode on menu to process

* Tue Feb 07 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 49f9c77
- version 1.0.1

* Tue Feb 07 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 46af3d3
- CI: add R4.2

* Tue Feb 07 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9722649
- Add qubes-builderv2 integration

* Mon Feb 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5df0abe
- version 1.0.0

* Mon Feb 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9a2a614
- make pylint happy

* Thu Feb 02 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - 3afccf1
- Fix move to/from events being ignored for .desktop files

* Tue Jan 03 2023 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - bf203c1
- Fix display of named disposable vms

* Mon Dec 19 2022 Marta Marczykowska-Górecka <marmarta@invisiblethingslab.com> - c14cbbb
- Make the menu into a systemctl service

* Mon Nov 14 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 87d8b50
- Fix --background causing menu to be always hiddden

* Sun Oct 30 2022 Andrew David Wong <adw@qubes-os.org> - 0576f3c
- Add Acknowledgements section thanking NLnet

* Fri Oct 28 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d78997c
- version 0.3.0

* Fri Oct 28 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 7998be5
- Make search more resilient to weird timing problems + fix keyboard nav

* Fri Oct 28 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - a0307a3
- Add Search to readme, update old images

* Thu Oct 27 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 9b38413
- Add functioning filter-by-qube to search

* Wed Oct 26 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 67f81c9
- Fix missing abstract def

* Wed Oct 26 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - beca6bc
- Add highlighting of search terms and fix styles

* Mon Oct 24 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 95fe628
- Introduce working search highlighting

* Sun Oct 23 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 59f09df
- Add highlighting of search terms

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 3f3388f
- Add recent searches

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 3b40aac
- Improvements to search algorith

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 0034dad
- Switch to search on typing

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 906f9ce
- Add icon to search barre

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 2830de7
- First working search

* Wed Oct 19 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 403856b
- Introduce an abstract PageHandler

* Tue Oct 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c7b2ab5
- version 0.2.2

* Tue Oct 18 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 6423a0e
- Remove unused imports

* Tue Oct 18 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - c25d6ba
- Fix app names to be more flexible

* Tue Oct 18 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 98f3501
- Fix problems with dispatching events, remove --restart

* Tue Oct 18 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - edb328c
- Fix minor display bug when switching menu tabs

* Mon Oct 17 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - aae41e8
- Fix pylint for new pylint version

* Mon Oct 17 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 5d4aa18
- Add support for dragging apps from menu

* Mon Oct 17 2022 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - f912ade
- Fix pylint for new pylint version

* Fri Nov 12 2021 Nina Eleanor Alter <ninavizz@gmail.com> - 09fca25
- Update README.md

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8ecd291
- version 0.2.1

* Fri Nov 05 2021 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - eba94eb
- Add hiding menu after second activation and fix hover state

* Thu Nov 04 2021 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 56caff8
- Fix rare bug with blank icon name

* Thu Nov 04 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7226991
- version 0.2.0

* Mon Nov 01 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b6c012b
- ci: install types-setuptools to make mypy happy

